import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixInnovationAssistantWidgetV1SettingsUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        _: [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'editor.wixapps.net': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/wix-assistant-widget',
                destPath: '',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_ai-site-chat_widget-settings';
/** Retrieves the widget settings for the site. */
export function getWidgetSettings(payload) {
    function __getWidgetSettings({ host }) {
        const metadata = {
            entityFqdn: 'wix.innovation.widget.v1.widget_settings',
            method: 'GET',
            methodFqn: 'wix.innovation.assistant.widget.v1.Settings.GetWidgetSettings',
            packageName: PACKAGE_NAME,
            url: resolveWixInnovationAssistantWidgetV1SettingsUrl({
                protoPath: '/v1/settings',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'widgetSettings.createdDate' },
                        { path: 'widgetSettings.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getWidgetSettings;
}
/** Sets the widget settings for the site. */
export function setWidgetSettings(payload) {
    function __setWidgetSettings({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'widgetSettings.createdDate' },
                    { path: 'widgetSettings.updatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.innovation.widget.v1.widget_settings',
            method: 'POST',
            methodFqn: 'wix.innovation.assistant.widget.v1.Settings.SetWidgetSettings',
            packageName: PACKAGE_NAME,
            url: resolveWixInnovationAssistantWidgetV1SettingsUrl({
                protoPath: '/v1/settings',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'widgetSettings.createdDate' },
                        { path: 'widgetSettings.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __setWidgetSettings;
}
//# sourceMappingURL=innovation-widget-v1-widget-settings-widget-settings.http.js.map