import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixInnovationWidgetV1WidgetSettings from './innovation-widget-v1-widget-settings-widget-settings.http.js';
export var OfflineBehavior;
(function (OfflineBehavior) {
    /** Unknown offline behavior. */
    OfflineBehavior["UNKNOWN_OFFLINE_BEHAVIOR"] = "UNKNOWN_OFFLINE_BEHAVIOR";
    /** Allows the site visitor to write messages, but doesn't send a contact form. */
    OfflineBehavior["CHAT_ONLY"] = "CHAT_ONLY";
    /** Hides the AI Site-Chat from the site. */
    OfflineBehavior["HIDE"] = "HIDE";
    /** Doesn't allow the site visitor to write messages, but does send a contact form. */
    OfflineBehavior["CONTACT_FORM_WITHOUT_CHAT"] = "CONTACT_FORM_WITHOUT_CHAT";
    /** Allows the site visitor to write messages and sends a contact form. */
    OfflineBehavior["CONTACT_FORM_WITH_CHAT"] = "CONTACT_FORM_WITH_CHAT";
})(OfflineBehavior || (OfflineBehavior = {}));
/**
 * Retrieves the widget settings for the site.
 * @public
 * @documentationMaturity preview
 * @permissionId INNOVATION_LAB.CHAT_WIDGET
 * @permissionScope Manage Bookings Services and Settings
 * @permissionScopeId SCOPE.BOOKINGS.CONFIGURATION
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @permissionScope Access Verticals by Automations
 * @permissionScopeId SCOPE.CRM.ACCESS-VERTICALS-BY-AUTOMATIONS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.innovation.assistant.widget.v1.Settings.GetWidgetSettings
 */
export async function getWidgetSettings() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    const payload = renameKeysFromSDKRequestToRESTRequest({});
    const reqOpts = ambassadorWixInnovationWidgetV1WidgetSettings.getWidgetSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {},
            singleArgumentUnchanged: false,
        }, []);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Sets the widget settings for the site.
 * @param widgetSettings - Widget settings to update.
 * @public
 * @documentationMaturity preview
 * @requiredField widgetSettings
 * @requiredField widgetSettings.activeHours
 * @requiredField widgetSettings.contactForm
 * @requiredField widgetSettings.contactForm.conditions
 * @requiredField widgetSettings.contactForm.fields
 * @requiredField widgetSettings.introMessage
 * @permissionId INNOVATION_LAB.CHAT_WIDGET_SETTINGS_SET
 * @fqn wix.innovation.assistant.widget.v1.Settings.SetWidgetSettings
 */
export async function setWidgetSettings(widgetSettings) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        widgetSettings: widgetSettings,
    });
    const reqOpts = ambassadorWixInnovationWidgetV1WidgetSettings.setWidgetSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { widgetSettings: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['widgetSettings']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=innovation-widget-v1-widget-settings-widget-settings.universal.js.map